@@ -13,11 +13,12 @@ use crate::core::{GenericResult, EmptyResult};
 use crate::formatting;
 use crate::localities::{self, Country, Jurisdiction};
 use crate::taxes::{TaxExemption, TaxPaymentDay, TaxPaymentDaySpec, TaxRemapping};
+use crate::telemetry::TelemetryConfig;
 use crate::time::{self, deserialize_date};
 use crate::types::{Date, Decimal};
 use crate::util::{self, DecimalRestrictions};
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct Config {
     #[serde(skip)]
@@ -32,16 +33,17 @@ pub struct Config {
     #[serde(default)]
     pub portfolios: Vec<PortfolioConfig>,
     pub brokers: Option<BrokersConfig>,
-
     #[serde(default)]
     pub tax_rates: TaxRates,
-
     #[serde(default)]
     pub metrics: MetricsConfig,
 
     pub alphavantage: Option<AlphaVantageConfig>,
     pub finnhub: Option<FinnhubConfig>,
     pub twelvedata: Option<TwelveDataConfig>,
+
+    #[serde(default)]
+    pub telemetry: TelemetryConfig,
 }
 
 impl Config {
@@ -62,6 +64,7 @@ impl Config {
             alphavantage: None,
             finnhub: None,
             twelvedata: None,
+            telemetry: Default::default(),
         }
     }
 
@@ -164,7 +167,7 @@ impl Config {
     }
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct DepositConfig {
     pub name: String,
@@ -184,7 +187,7 @@ pub struct DepositConfig {
     pub contributions: Vec<(Date, Decimal)>,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct PortfolioConfig {
     pub name: String,
@@ -257,7 +260,7 @@ impl PortfolioConfig {
     }
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 struct TaxRemappingConfig {
     #[serde(deserialize_with = "deserialize_date")]
@@ -267,7 +270,7 @@ struct TaxRemappingConfig {
     pub to_date: Date,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 pub struct AssetAllocationConfig {
     pub name: String,
     pub symbol: Option<String>,
@@ -294,7 +297,7 @@ impl AssetAllocationConfig {
     }
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct BrokersConfig {
     pub bcs: Option<BrokerConfig>,
@@ -317,7 +320,7 @@ impl BrokersConfig {
     }
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(deny_unknown_fields)]
 pub struct BrokerConfig {
     pub deposit_commissions: HashMap<String, TransactionCommissionSpec>,
@@ -332,7 +335,7 @@ impl BrokerConfig {
     }
 }
 
-#[derive(Deserialize, Default, Debug)]
+#[derive(Deserialize, Default)]
 #[serde(deny_unknown_fields)]
 pub struct TaxRates {
     #[serde(default)]
@@ -343,32 +346,32 @@ pub struct TaxRates {
     pub interest: BTreeMap<i32, Decimal>,
 }
 
-#[derive(Deserialize, Default, Debug)]
+#[derive(Deserialize, Default)]
 #[serde(deny_unknown_fields)]
 pub struct MetricsConfig {
     #[serde(default)]
     pub merge_performance: PerformanceMergingConfig,
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(deny_unknown_fields)]
 pub struct TransactionCommissionSpec {
     pub fixed_amount: Decimal,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct AlphaVantageConfig {
     pub api_key: String,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct FinnhubConfig {
     pub token: String,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct TwelveDataConfig {
     pub token: String,
